@@ -6,7 +6,9 @@ package Net::BitTorrent::Protocol;
     use Carp qw[carp];
     use lib q[../../../lib];
     use Net::BitTorrent::Util qw[:bencode];
-    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), ($VERSION_BASE / 1000), $UNSTABLE_RELEASE);
+    use version qw[qv];
+    our $SVN = q[$Id: Protocol.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
     use vars qw[@EXPORT_OK %EXPORT_TAGS];
     use Exporter qw[];
     *import = *import = *Exporter::import;
@@ -20,11 +22,7 @@ package Net::BitTorrent::Protocol;
         _parse_port _parse_suggest _parse_have_all _parse_have_none
         _parse_reject _parse_allowed_fast _parse_extended HANDSHAKE KEEPALIVE
         CHOKE UNCHOKE INTERESTED NOT_INTERESTED HAVE BITFIELD REQUEST PIECE
-        CANCEL PORT SUGGEST HAVE_ALL HAVE_NONE REJECT ALLOWED_FAST EXTPROTOCOL
-        _build_dht_reply_get_peers _build_dht_query_get_peers
-        _build_dht_reply_values    _build_dht_query_announce
-        _build_dht_reply_ping      _build_dht_query_ping
-        _build_dht_reply_find_node _build_dht_query_find_node];
+        CANCEL PORT SUGGEST HAVE_ALL HAVE_NONE REJECT ALLOWED_FAST EXTPROTOCOL];
     %EXPORT_TAGS = (
         all   => [@EXPORT_OK],
         build => [
@@ -46,16 +44,7 @@ package Net::BitTorrent::Protocol;
             qw[HANDSHAKE KEEPALIVE CHOKE UNCHOKE INTERESTED NOT_INTERESTED
                 HAVE BITFIELD REQUEST PIECE CANCEL PORT SUGGEST HAVE_ALL
                 HAVE_NONE REJECT ALLOWED_FAST EXTPROTOCOL]
-        ],
-        dht => [
-            qw[_build_dht_reply_get_peers _build_dht_query_get_peers
-                _build_dht_reply_values    _build_dht_query_announce
-                _build_dht_reply_ping      _build_dht_query_ping
-                _build_dht_reply_find_node _build_dht_query_find_node]
-        ],
-
-        # XXX - Move MSE-related functions from N::B::Peer
-        #mse => [qw[  ]]
+        ]
     );
     sub HANDSHAKE      {-1}
     sub KEEPALIVE      {q[]}
@@ -248,24 +237,6 @@ package Net::BitTorrent::Protocol;
         my $packet = pack(q[ca*], $msgID, bencode($data));
         return pack(q[Nca*], length($packet) + 1, 20, $packet);
     }
-    my %parse_packet_dispatch = (&KEEPALIVE      => \&_parse_keepalive,
-                                 &CHOKE          => \&_parse_choke,
-                                 &UNCHOKE        => \&_parse_unchoke,
-                                 &INTERESTED     => \&_parse_interested,
-                                 &NOT_INTERESTED => \&_parse_not_interested,
-                                 &HAVE           => \&_parse_have,
-                                 &BITFIELD       => \&_parse_bitfield,
-                                 &REQUEST        => \&_parse_request,
-                                 &PIECE          => \&_parse_piece,
-                                 &CANCEL         => \&_parse_cancel,
-                                 &PORT           => \&_parse_port,
-                                 &SUGGEST        => \&_parse_suggest,
-                                 &HAVE_ALL       => \&_parse_have_all,
-                                 &HAVE_NONE      => \&_parse_have_none,
-                                 &REJECT         => \&_parse_reject,
-                                 &ALLOWED_FAST   => \&_parse_allowed_fast,
-                                 &EXTPROTOCOL    => \&_parse_extended
-    );
 
     sub parse_packet {
         my ($data) = @_;
@@ -287,8 +258,26 @@ package Net::BitTorrent::Protocol;
         {   if ((unpack(q[N], $$data) <= length($$data))) {
                 (my ($packet_data), $$data) = unpack(q[N/aa*], $$data);
                 (my ($type), $packet_data) = unpack(q[ca*], $packet_data);
-                if (defined $parse_packet_dispatch{$type}) {
-                    my $payload = $parse_packet_dispatch{$type}($packet_data);
+                my %dispatch = (&KEEPALIVE      => \&_parse_keepalive,
+                                &CHOKE          => \&_parse_choke,
+                                &UNCHOKE        => \&_parse_unchoke,
+                                &INTERESTED     => \&_parse_interested,
+                                &NOT_INTERESTED => \&_parse_not_interested,
+                                &HAVE           => \&_parse_have,
+                                &BITFIELD       => \&_parse_bitfield,
+                                &REQUEST        => \&_parse_request,
+                                &PIECE          => \&_parse_piece,
+                                &CANCEL         => \&_parse_cancel,
+                                &PORT           => \&_parse_port,
+                                &SUGGEST        => \&_parse_suggest,
+                                &HAVE_ALL       => \&_parse_have_all,
+                                &HAVE_NONE      => \&_parse_have_none,
+                                &REJECT         => \&_parse_reject,
+                                &ALLOWED_FAST   => \&_parse_allowed_fast,
+                                &EXTPROTOCOL    => \&_parse_extended
+                );
+                if (defined $dispatch{$type}) {
+                    my $payload = $dispatch{$type}($packet_data);
                     $packet = {Type => $type,
                                (defined $payload
                                 ? (Payload => $payload)
@@ -437,181 +426,11 @@ END
         return unpack(q[N], $packet);
     }
 
-    sub _parse_extended_old {
-        my ($packet) = @_;
-        if ((!$packet) || (!length($packet))) { return; }
-        my ($id, $payload) = unpack(q[ca*], $packet);
-        return ([$id, scalar bdecode($payload)]);
-    }
-
     sub _parse_extended {
         my ($packet) = @_;
         if ((!$packet) || (!length($packet))) { return; }
         my ($id, $payload) = unpack(q[ca*], $packet);
-        ($payload, my $data) = bdecode($payload);
-        $payload->{q[DATA]} = $data if $data;
-        return ([$id, $payload]);
-    }
-
-    sub _build_dht_query_ping {
-        my ($tid, $id) = @_;
-        if (!defined $tid) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_ping() requires a 'token id' parameter];
-            return;
-        }
-        if (!defined $id) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_ping() requires an 'client id' parameter];
-            return;
-        }
-        return
-            bencode({t => $tid,
-                     y => q[q],
-                     q => q[ping],
-                     a => {id => $id},
-                     v => q[NB00]
-                    }
-            );
-    }
-
-    sub _build_dht_query_announce {
-        my ($tid, $id, $infohash, $token, $port) = @_;
-        if (!defined $tid) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_announce() requires a 'token id' parameter];
-            return;
-        }
-        if (!defined $id) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_announce() requires an 'client id' parameter];
-            return;
-        }
-        if (!defined $token) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_announce() requires an 'token' parameter];
-            return;
-        }
-        if ((!defined $infohash) || (length($infohash) != 20)) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_announce() requires an 'infohash' parameter];
-            return;
-        }
-        if ((!defined $tid) || ($port !~ m[^\d+$])) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_ping() requires a 'port' parameter];
-            return;
-        }
-        return
-            bencode({t => $tid,
-                     y => q[q],
-                     q => q[announce_peer],
-                     a => {id        => $id,
-                           port      => $port,
-                           info_hash => $infohash,
-                           token     => $token
-                     },
-                     v => q[NB00]
-                    }
-            );
-    }
-
-    sub _build_dht_query_find_node {
-        my ($tid, $id, $target) = @_;
-        if (!defined $tid) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_find_node() requires a 'token id' parameter];
-            return;
-        }
-        if (!defined $id) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_find_node() requires an 'client id' parameter];
-            return;
-        }
-        if ((!defined $target) || (length($target) != 20)) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_find_node() requires an 'target' parameter];
-            return;
-        }
-        return
-            bencode({t => $tid,
-                     y => q[q],
-                     q => q[find_node],
-                     a => {id     => $id,
-                           target => $target
-                     },
-                     v => q[NB00]
-                    }
-            );
-    }
-
-    sub _build_dht_query_get_peers {
-        my ($tid, $id, $info_hash) = @_;
-        if (!defined $tid) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_get_peers() requires a 'token id' parameter];
-            return;
-        }
-        if (!defined $id) {
-            carp
-                q[Net::BitTorrent::Protocol::_build_dht_query_get_peers() requires an 'client id' parameter];
-            return;
-        }
-        if ((!defined $info_hash) || (length($info_hash) != 20)) {
-            Carp::confess
-                q[Net::BitTorrent::Protocol::_build_dht_query_get_peers() requires an 'info_hash' parameter];
-            return;
-        }
-        return
-            bencode({t => $tid,
-                     y => q[q],
-                     q => q[get_peers],
-                     a => {id => $id, info_hash => $info_hash},
-                     v => q[NB00]
-                    }
-            );
-    }
-
-    sub _build_dht_reply_ping {
-        my ($tid, $id) = @_;
-        return bencode(
-                      {t => $tid, y => q[r], r => {id => $id}, v => q[NB00]});
-    }
-
-    sub _build_dht_reply_find_node {
-        my ($tid, $id, $nodes) = @_;
-        return
-            bencode({t => $tid,
-                     y => q[r],
-                     r => {id => $id, nodes => $nodes},
-                     v => q[NB00]
-                    }
-            );
-    }
-
-    sub _build_dht_reply_get_peers {
-        my ($tid, $id, $nodes, $token) = @_;
-        return
-            bencode({t => $tid,
-                     y => q[r],
-                     r => {id => $id, token => $token, nodes => $nodes},
-                     v => q[NB00]
-                    }
-            );
-    }
-
-    sub _build_dht_reply_values {
-        my ($tid, $id, $values, $token) = @_;
-        return
-            bencode({t => $tid,
-                     y => q[r],
-                     r => {id     => $id,
-                           token  => $token,
-                           values => $values
-                     },
-                     v => q[NB00]
-                    }
-            );
+        return ([$id, scalar bdecode($payload)]);
     }
     1;
 }
@@ -719,7 +538,7 @@ the BitTorrent spec:
 
 =over
 
-=item C<RESERVED>
+=item C<RESEREVED>
 
 ...is the 8 byte string used to represent a client's capabilities for
 extensions to the protocol.
@@ -973,7 +792,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -989,6 +808,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Protocol.pm 5476ff9 2009-09-07 04:37:45Z sanko@cpan.org $
+=for svn $Id: Protocol.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
 
 =cut
