@@ -24,8 +24,8 @@ package Net::BitTorrent::Torrent;
     use Net::BitTorrent::Torrent::File;
     use Net::BitTorrent::Torrent::Tracker;
     use version qw[qv];
-    our $SVN = q[$Id: Torrent.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 9; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    our $SVN = q[$Id: Torrent.pm 42 2008-12-05 04:54:43Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 9; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 42 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
     my %REGISTRY = ();
     my @CONTENTS = \my (%_client,       %path,     %basedir,
                         %size,          %files,    %trackers,
@@ -882,7 +882,7 @@ package Net::BitTorrent::Torrent;
     }
 
     # Private | Utility
-    sub _as_string {
+    sub as_string {
         my ($self, $advanced) = @_;
         my $wanted = $self->_wanted;
         my $dump = !$advanced ? $self->infohash : sprintf <<'END',
@@ -960,11 +960,11 @@ END
                 } sort { $a <=> $b } keys %{$working_pieces{refaddr $self}}
             ),
             (join qq[\r\n],
-             map { qq[\r\n] . $_->_as_string(0) } @{$files{refaddr $self}}
+             map { qq[\r\n] . $_->as_string(0) } @{$files{refaddr $self}}
             ),
             (scalar @{$trackers{refaddr $self}}
              ?
-                 map { qq[\r\n] . $_->_as_string($advanced) }
+                 map { qq[\r\n] . $_->as_string($advanced) }
                  @{$trackers{refaddr $self}}
              : q[]
             ),
@@ -1406,6 +1406,12 @@ started transferring data related to this .torrent.
 
 See also: L<downloaded ( )|/"downloaded ( )">
 
+=item C<as_string ( [ VERBOSE ] )>
+
+Returns a 'ready to print' dump of the  object's data structure.  If
+called in void context, the structure is printed to C<STDERR>.
+C<VERBOSE> is a boolean value.
+
 =back
 
 =head1 Events
@@ -1443,6 +1449,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Torrent.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
+=for svn $Id: Torrent.pm 42 2008-12-05 04:54:43Z sanko@cpan.org $
 
 =cut
