@@ -11,8 +11,8 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
     use lib q[../../../../../lib];
     use Net::BitTorrent::Util qw[:bencode uncompact];
     use version qw[qv];
-    our $SVN = q[$Id: HTTP.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 40 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    our $SVN = q[$Id: HTTP.pm 42 2008-12-05 04:54:43Z sanko@cpan.org $];
+    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 42 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
     my (@CONTENTS)
         = \my (%_url, %_tier, %resolve, %_event, %_socket, %_data_out);
     my %REGISTRY;
@@ -306,7 +306,7 @@ package Net::BitTorrent::Torrent::Tracker::HTTP;
         return ($actual_read, $actual_write);
     }
 
-    sub _as_string {
+    sub as_string {
         my ($self, $advanced) = @_;
         my $dump = !$advanced ? $$self : sprintf <<'END',
 Net::BitTorrent::Torrent::Tracker::HTTP
@@ -356,6 +356,18 @@ constructor should not be used directly.
 
 =back
 
+=head1 Methods
+
+=over
+
+=item C<as_string ( [ VERBOSE ] )>
+
+Returns a 'ready to print' dump of the  object's data structure.  If
+called in void context, the structure is printed to C<STDERR>.
+C<VERBOSE> is a boolean value.
+
+=back
+
 =head1 BUGS/TODO
 
 =over 4
@@ -390,6 +402,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: HTTP.pm 40 2008-12-02 04:25:26Z sanko@cpan.org $
+=for svn $Id: HTTP.pm 42 2008-12-05 04:54:43Z sanko@cpan.org $
 
 =cut
